"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const wxmlParser_1 = require("./parser/wxmlParser");
const wxmlDiagnostic_1 = require("./services/wxmlDiagnostic");
const wxmlComplete_1 = require("./services/wxmlComplete");
const wxmlHover_1 = require("./services/wxmlHover");
let cache = {};
function getManager() {
    let config = {
        complete: {
            useSnippet: false,
            completeEvent: true
        }
    };
    return {
        setConfig(obj) {
            config = Object.assign(config, obj);
        },
        getWxmlDocument(document) {
            let { uri } = document;
            let doc = cache[uri];
            if (doc)
                return doc;
            return this.parse(document);
        },
        parse(document) {
            let { uri } = document;
            let doc = wxmlParser_1.parse(document.getText());
            cache[uri] = doc;
            return doc;
        },
        removeDocument(uri) {
            delete cache[uri];
        },
        doDiagnostic(document) {
            let doc = this.parse(document);
            return wxmlDiagnostic_1.default(document, doc);
        },
        doHover(document, position) {
            let doc = this.getWxmlDocument(document);
            return wxmlHover_1.default(document, position, doc);
        },
        doComplete(document, position) {
            let doc = this.getWxmlDocument(document);
            return wxmlComplete_1.default(document, position, doc, config.complete);
        }
    };
}
exports.getManager = getManager;
//# sourceMappingURL=manager.js.map