"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_jsonrpc_1 = require("vscode-jsonrpc");
const vscode_languageserver_1 = require("vscode-languageserver");
const net = require("net");
const stream = require("stream");
function connectionFromOptions(options) {
    let reader;
    let writer;
    switch (options.method) {
        case 'socket':
            // For socket connection, the message connection needs to be
            // established before the server socket starts listening.
            // Do that, and return at the end of this block.
            writer = new stream.PassThrough();
            reader = new stream.PassThrough();
            let server = net
                .createServer(socket => {
                server.close();
                socket.pipe(reader);
                writer.pipe(socket);
            })
                .listen(options.port);
            break;
        case 'node-ipc':
            reader = new vscode_jsonrpc_1.IPCMessageReader(process);
            writer = new vscode_jsonrpc_1.IPCMessageWriter(process);
            break;
        case 'stdio':
        default:
            reader = process.stdin;
            writer = process.stdout;
            break;
    }
    return vscode_languageserver_1.createConnection(reader, writer);
}
exports.default = connectionFromOptions;
//# sourceMappingURL=connectionFromOptions.js.map